#import "@preview/accelerated-jacow:0.1.3": jacow, jacow-table
#import "@preview/unify:0.7.1": unit, num, qty, numrange, qtyrange
#import "@preview/glossy:0.7.0": init-glossary
#import "@preview/lilaq:0.1.0" as lq
#import "@preview/physica:0.9.5": *

//####################
//# - Global Setup
//####################
#set page(
  width: 21cm,
  height: 29.7cm,
) // A4 size

//####################
//# - Title Page
//####################
#align(center)[
  #v(1cm)
  #image("dtu-logo.png"),
  #box(height: 2cm)
  #line(length: 15cm)
  #text(size: 18pt)[*Material Identification*]
  
  #text(size: 14pt)[41685 - Materials Characterization and Testing]

  #text(size: 10pt)[Sofus Rose (s174509), Harjas Preet (s215168), Ulises Lozoya (s234527)]
  #line(length: 15cm)
]

#place(
  horizon + left,
  dx: 0.75cm,
  dy: 3cm,
  text(size: 10pt)[
    #align(center)[_Abstract_]
    
    An unknown material is investigated and identified using the techniques and equipment explored during the course `Materials Characterization and Testing` (41685).
    By determining the composition, microstructure and mechanical properties of the sample, the sample was identified as `Duplex Stainless Steel 2205`.
    This report demonstrates the characterization methods learnt through in the course 41685, which ran in Spring, 2025.
  ]
)

//####################
//# - Body Setup
//####################
#set page(
  footer: context[
    #line(length: 18cm)
    //#place(
    //  bottom + center,
    //  dy:1.2pt,
    //  image("dtu logog.png"),
    //)
    #place(
      horizon + center,
      counter(page).display(
        "1 of 1",
        both: true,
      )
    )
  ]
)

#show: jacow.with()



//####################
//# - Section: Introduction
//####################
= Introduction
The objective of this project was to identify an unknown sample using a variety of material characterization techniques.
To this end, various techniques covered in the course were employed, including LOM, SEM, EDS, XRD and hardness testing.


//####################
//# - Section: Methods
//####################
= Methods
Two samples of the same material, @fig:sample-uncoated and @fig:sample-coated, are considered in this report.

#figure(
  rect(image("images/sample-uncoated.jpeg")),
  caption: [
    The uncoated sample.
  ],
) <fig:sample-uncoated>

#figure(
  rect(image("images/sample-coated.jpeg")),
  caption: [
    The coated sample.
  ],
) <fig:sample-coated>

The two samples were prepared by the instructors prior to analysis.
This preparation included sectioning and embedding for both samples.
The "uncoated" sample was additionally acid-etched by the instructors.

In order to avoid contamination with oils from human skin, direct tactile contact with the studied sample surfaces was avoided at all times.
The box containing the samples was also kept closed to the extent possible.

The samples were tested for magnetism on a macroscopic scale, using standard magnets.



== Light Optical Microscopy (LOM)
The purpose of performing an LOM investigation was to qualitatively assess the exposed microstructure of the samples.

Both samples were initially inspected using the 5x objective lens, without any filters.
This was done in order to facilitate navigation at higher magnifications, in the absence of any preconceived features of interest.
This also helped establish the border between the embedding resin and the sample, to ensure that closer analysis would not inadvertently focus on the polymer resin.

Gradually, increasing magnifications were utilized to perform closer examinations.
Use of spectral filters was not deemed necessary in this case, as the qualitative microstructure was quite evident.



== Scanning Electron Microscopy (SEM)
The purpose of performing a SEM investigation was to qualitatively confirm the microstructures assessed by LOM, as well as establish the presence of such structures slightly inside of the samples.

Both samples were secured to a pedestal using non-conductive carbon tape, then placed in the vacuum chamber of the SEM microscope.
Gloves were used to avoid contamination of the sample and of the SEM chamber.
The visualizations were started in secondary electron scattering mode (SEI), using PC-High, 10kW, and the minimum magnification of 22x.

SEM images were then recorded at various magnifications, in order to explore the topography of the sample surface.



== Energy Dispersive X-ray Spectroscopy (EDS)
The purpose of performing an EDS investigation was to quantitatively determine the elemental composition of the samples.

SEM and EDS both rely on an electron beam interacting with a sample.
In EDS, the electron beam probabilistically removes electrons from the inner valence shells of atoms present in the sample surface.
These vacancies are then quickly filled by electrons from higher energy orbit.
During this process, energy is sometimes emitted in the form of x-rays.

The mechanism of EDS is to detect the x-rays generated in this way, thus slowly sampling a precise "fingerprint" of elemental identity.
In particular, EDS is excellent at reconstructing the relative mass of heavier elements present in metallic samples.

Both samples were analyzed using the EDS function of the SEM microscope.
The composition of single points, as well as of an entire imaged region, were sampled as well.



== X-ray Diffraction (XRD)
The purpose of performing an XRD investigation was to quantitatively determine the crystal structure of the samples.

In an XRD analysis, x-rays are directed at the surface of a material that is known or suspected of having crystalline properties.
When the incident x-rays interact with the sample and scatter in many directions, a detector may be used to reconstruct the distribution of scattering events.

In general, the distribution of x-ray scattering depends on the spacing between planes of reflection and the incident angle of the x-rays.
In XRD, the incident angle of the x-rays is precisely set, such that the resulting interference pattern can be used to reconstruct the spacing between the atomic planes of the sample.

XRD works because atomic periodicity _generates_ planes of reflection.
In other words, atoms in a crystal will "line up just right" at specific angles, reflecting x-rays exactly as a "stack of reflection planes" might.
This phenomenon of stacked reflections may then be modelled by Bragg's law
$ n lambda = 2d sin(theta) $
where n is an integer describing the resulting constructive interference, $lambda$ is the wavelength of the x-ray beam, $d$ is the spacing between atomic planes and $theta$ is the angle at which the x-ray beam hits the plane. 

To estimate the spacing between atomic planes $d$, one performs an XRD experiment and records the values of $theta$ that produced the largest reflections.
Then, the relationship between the spacing distance, the lattice parameter (a), and the Miller indices (h,k,l) of the crystal's unit cell may be modelled: 
$
  1/d^2 & = ((2sin(theta))/lambda)^2 = (h^2 + k^2 + l^2)/a^2
$

Since the expected peaks $(h^2 + k^2 + l^2)/a^2$ of many structures are already known,#footnote[There are a variety of crystallographic databases available to find such candidates. Otherwise, it may sometimes be possible to combinatorially deduce possible "explanations" for an experimental result.] one may match the experimentally observed $((2sin(theta))/lambda)^2$ in order to reconstruct the atomic crystal structure of the sample.

Both samples underwent an XRD analysis.
The scan was performed over a $2 theta$ range, from 40° to 102.9°.
1.5406Å Cu - K#sym.alpha radiation was chosen due to its advantageous resolution in the analysis of common metals and alloys.



== Hardness testing (HV)
The purpose of performing a hardness test was to challenge an existing hypothesis of the sample's identity, by determining whether the sample's hardness would agree with the proposed material.

Only the uncoated sample was used for hardness testing.
A micro-indentation was then performed in a laboratory with 50% relative air humidity, at a strength of 1kg, by an instructor.
Three micro-indentations were performed in this manner.
In this process, a 50x objective lens was used to verify that the indentations were performed into an un-indented portion of the sample.



//####################
//# - Section: Discussion
//####################
= Results
The result of the test for magnetism was positive; the sample was indeed magnetic.

== Analysis of LOM
Images of the uncoated sample, using 10x and 100x objective lenses, are included respectively as @fig:lm-10x-uncoated and @fig:lm-100x-uncoated.
The grain structure is eminently clear, thanks to the use of acid etching before this analysis.

#figure(
  image("10x.png"),
  caption: [
    Micrograph of the uncoated sample at 10x.
    The dark square patches are indentations from mechanical testing, from before this analysis.
    
    _NOTE: The scale bar in this image is incorrect._
  ],
) <fig:lm-10x-uncoated>

#figure(
  image("100x.png"),
  caption: [
    Micrograph of the uncoated sample at 100x.
    Note that neither of the scales in these 2 figures are correct.
    
    _NOTE: The scale bar in this image is incorrect._
  ]
)<fig:lm-100x-uncoated>

Images of the coated sample were also recorded using various objectives.
LOM analysis of the coated sample was not so effective, as the microstructure was obfuscated by the coating.
This situation is clearly visible in the 50x-objective image, @fig:lm-50x-coated.

Notably, the 5x-objective image @fig:lm-5x-coated also reveals numerous scratches and physical damages, provoking caution.

In the 10x-objective image of the uncoated sample, @fig:lm-10x-uncoated, an aligned directional elongation of the crystal grain structure is clearly visible.
This suggests that the sample has undergone mechanical processing such as forging or rolling.

In the 100x-objective image of the uncoated sample, @fig:lm-100x-uncoated, the finer details of this structure may be examined.

The magnetism of the sample suggests the presence of BCC ferritic phases, but the qualitative microstructure would seem to suggest an FCC austenitic identity.#footnote[
  An educational poster from the laboratory, @fig:carbonsteels, was referenced to help guide this analysis.
]
It should be noted that there is no evidence of "deformation twinning", which requires "gliding" displacement along a crystallographic plane.

Despite the austenitic appearance, this sample must be "dual-phase", since it is magnetic.
This suggests that while the surface contains mostly austenitic phases, ferritic phases must be be more prominent within the material.
The purpose of such a construction suggests an application where corrosion-resistance is needed, for example specialized kinds of tanks or coastal pipes; surface-region magnetism is presumably not an advantage here. //The sample IS magnetic, so why would they make a sample "not magnetic" while still keeping the magnetism?



== Analysis of SEM
The surface of the uncoated sample was determined to be quite homogeneous, and the borders between the grains contrasted strongly.
This is consistent with the use of acid etching for preparing the sample.#footnote[
  Since grain boundaries tend to be more chemically reactive, one may generally observe a characteristic "deepening" of the geometry surrounding etched grain boundaries.
  Perceptually, this  presents as higher contrast in the geometry of SEM imaging.
]

#figure(
  image("images/sei.jpg"),
  caption: [
    SEI image of the uncoated sample. _A microindentation from previous hardware testing is visible._
  ],
) <fig:sei>


At higher magnifications, details of the microstructure were also visible under the SEM, as can be seen in @fig:sei.
Qualitatively, this agreed with the structures visible under a LOM.

The presence of previously performed mechanical indentation testing is also noted in the SEM images.
These indentations displayed a different microstructure, but for for consistency, an analysis of this was excluded.

The microstructure of the coated sample seemed to agree with that of the uncoated sample.
However, it is not certain: The SEM microscopes used in this analysis were not powerful enough to penetrate the coating and resolve the subsurface structures.#footnote[The ability to do so is why etching is useful!] Generally, however, SEM microscopes can be utilized in such situations.



== Analysis of EDS
For the EDS functionality, it was correctly hypothesized that the uncoated sample would show a higher light-element content.

Unfortunately, the `C` composition suggested by the EDS device may be inaccurate.
The accuracy of this EDS device was relatively low, as evidenced by the variance of the noise floor in the lighter elements.
Therefore, the relative mass of `C` may be "hiding" various other light elements, such as `O` or `N`.

Since the coated sample displayed a significantly higher percentage of light elements (see @fig:eds-coated), the uncoated sample was prioritized in the composition analysis.
These results are given in @fig:eds-uncoated and @fig:eds-uncoated-table.

#figure(
  image("images/eds-uncoated.png"), 
  caption: [Chemical compounds present in the sample]
) <fig:eds-uncoated>

#place(
  top + center,
  scope: "parent",
  float: true,
  [
    #figure(
      image("images/eds-uncoated-table.png"),
      caption: [Elemental composition of the uncoated sample. ]
    ) <fig:eds-uncoated-table>
  ]
)


The approximate composition of the uncoated sample was therefore: `Fe` (62.95%), `Cr` (24.46%), `Ni` (4.9%), `Mo` (3.06%), `Mn` (2.47%), `C` (1.70%), `Si` (0.39%).

An image map of the composition was also recorded in @fig:eds-map.



It is _immediately_ apparent from the `Fe` and `Cr` content that this sample is a stainless steel incorporating `Mo` and `Ni`.
As noted, it's not possible to determine the contribution of lighter elements such as `C` and `N` from this particular EDS analysis.

The very low `Si` content of 0.39% was (prematurely) presumed to be the product of contamination.



== Analysis of XRD
The XRD analysis of the uncoated sample is given as @fig:xrd.

#figure(
  image("images/xrd.png"),
  caption: [XRD analysis of the sectioned sample]
) <fig:xrd>

With minor lateral adjustments, pure iron (PDF 06-0696) matched the experimental XRD values.

A pearlite phase was tried, but it did not match the experimental results.
Austenitic steel was then tried, resulting in a match.

After `Fe`, `Cr` and `Ni` exhibited the the highest relative mass.
Therefore, an attempt was made to match Chromium - Iron - Nickel Austenite (PDF 33-0397).
This successfully matched the leftover peaks.

The leftover peak which was attributed to instrumentation error.#footnote[
  Apparently, the tungsten tube can sometimes impose this small peak. The `Cu`-$K_alpha$ X-Ray used to sample can also infiltrate the XRD.//i just wanna add Cu K_alpha
]

Intriguingly, the XRD displays diffraction peaks consistent with _both_ FCC and BCC phases.#footnote[
  FCC corresponds to the non-magnetic austenitic phase, while BCC corresponds to magnetic ferrite phase.
]
It's therefore likely that the sample has a dual-phase structure.



== Analysis of Hardness Testing
The values 246HV, 250HV, and 254HV were found, averaging to 250 HV.
In GPa:

$
250"HV" dot 0.009807 "GPa"/"HV" = 2.45 "Gpa"
$



//####################
//# - Section: Discussion
//####################
= Discussion
Of all the results, the most significant was the non-`C` elemental composition, and the dual-phase structure with seemingly austenitic surface.

Comparing all results with a known database, these features align very closely to Duplex Stainless Steel 2205. @Stainless_Steel_Grade_2205_Duplex_UNS_S32205_2001.

== Matching the Composition
Duplex Stainless Steel 2205 requires, in particular, $"C" < 0.03%$, Cr between 21-23%, Ni between 4.5-6.5%, Mo between 2.5-3.5%, N between 0.8-2.0%, $"Mn" < 2%$, $"Si" < 1%$, $"P" < 0.03%$, $"S" < 0.02%$.

The leg of this hypothesis lies in the composition.
In particular, the experimental `Cr`, `Ni`, `Mn`, and `Mo` content conforms reasonably well in light of the instrument's accuracy.

Due to that lacking accuracy of the EDS instrument, it's impossible to determine how much of the measured `C` content is _actually_ an indication of other light elements such as `N`.
The hypothesis therefore cannot not hinge on the experimental `C` composition; rather, it is the heavier and more accurately measurable elements that form the "fingerprint" of interest.

The last dissonance lies in `S` and `P`, which are not accounted for experimentally.
Duplex Stainless Steel 2205 allows for very low upper bounds that neither exclude a valid value of $0$, nor rule out inaccuracies in instrumentation.

== Matching the Structure
The next leg of this hypothesis lie dual-phase structure.
This, in particular, is a unique fingerprint of duplex stainless steels.#footnote[
  This is indeed what makes them "duplex"!
]

Duplex ferritic-austenitic stainless steels exhibit excellent corrosion resistance, weldability, and strength in applications such as gas pipes on offshore platforms. @Wang2023

What is not so easily accounted for is the seemingly austenitic surface of this magnetic, dual-phase sample.
Due to previously noted instrumentation errors, it's therefore entirely plausible that a significant quantity of the rather large `C` mass content is actually some other element, such as (leadingly) `N`.
This observation is particularly salient when considering the DTU-based study @Wang2023, wherein:

_#quote[
  Annealed steels were subsequently subjected to high-temperature solution nitriding, which transformed the surface-adjacent region into austenite under the influence of nitrogen ingress
]_

In identifying the samples, a case can therefore be made for a process whereby nitrogen was used to impregnate the surface of a 2205 duplex steel at a temperature between 1000 and 1200 degrees C, as described in @Wang2023.

== Matching the Hardness
While the conclusion is somewhat established prior to the Hardness Testing, this last additional test was performed to verify the educated guess. 

The maximum Rockwell hardness for Stainless Steel 2205 is 31. @ASTM_A240_UNS_S32205_Duplex_Stainless_Steel_Plates
When converting the measured hardness, the Rockwell hardness of this sample is around 26; this is slightly softer than the average, but within the acceptable range for this steel.



//####################
//# - Section: Conclusion
//####################
= Conclusion
Following these findings, it is determined with reasonable confidence that this mysterious sample is a `Duplex Stainless Steel 2205`.

Moreover, it is strongly suspected that this sample has been hardened by high-temperature solution nitriding, in order to enhance non-magnetic austenitic phase of the surface regions and improve certain properties incl. corrosion resistance.#footnote[
  It was inevitably _speculated_ by the authors of this report that the analyzed sample perhaps _is_ the material described in @Wang2023.
  The data alone indicates, but does not verify this conclusion.
  It was merely noted that one of the co-authors of @Wang2023, Marcel A. J. Somers, is also an instructor of 41685, which runs at the same institution...

  We were asked to be detectives, after all!!
]

A few mistakes were made during the course of this analysis.
First and foremost, the scale bars in the LOM analysis were _completely meaningless_, due to user error when using the the LOM software.
While it may be possible to use the indentation size to reconstruct the scale, this is a rather unfortunate mistake that ex. makes it impossible to measure the grain size.

Secondly, the XRD is performed using a `304` stainless steel, which is somewhat different than a `2205` stainless steel - ideally, one would locate a diffractogram for `2205` steel instead.

That the sample is `Duplex Stainless Steel 2205` has been concluded, but the use of nitriding is only strongly suspected.
The use of this process, as well as the exact temperature used to generate it, could be verified by:
- Analyzing the ratio of ferrite / austenite on the surface versus the interior of the sample, since the interior is expected to display higher ferrite content & magnetism in relation to the nitrided surface region.
- Statistically measuring the grain size on the interior / surface, as this is directly correlated to the annealing temperature.
- Booking time on a more accurate EDS instrument, to produce a more accurate and trustworthy compositional analysis. In particular, this would make it possible to differentiate `C` from `N` and other lightweight elements, making it possible to analyze the `N` content of the sample's interior versus it's surface and conclusively determine whether it was nitrided - as well as what, exactly, the lightweight coating on one of the samples is made of.



//####################
//# - Section: Bibliography
//####################
#bibliography("references.bib")



//####################
//# - Section: Appendix
//####################
#pagebreak()
#set heading(numbering: "A", supplement: [Appendix])

#place(
  top + center,
  scope: "parent",
  float: true,
  [= Appendix]
)

#place(
  top + center,
  scope: "parent",
  float: true,
  [
    #figure(
      [
        #grid(
          columns: 2,
          gutter: 2mm,
          image("images/composition/C_K.jpg"),
          image("images/composition/Cr_K.jpg"),
          image("images/composition/Fe_K.jpg"),
          image("images/composition/Mn_K.jpg"),
          image("images/composition/Mo_L.jpg"),
          image("images/composition/Ni_K.jpg"),
        )
      ],
      caption: [EDS map of key elements present in the sample. _Note the change in magnitude within the microindentation, which is due to the angle at which the beam is incident; this should be excluded from the analysis, and highlights the importance of analyzing a topologically homogeneous surface._]
    ) <fig:eds-map>
  ]
)
#pagebreak()

#place(
  top + center,
  scope: "parent",
  float: true,
  [
    #let width = 75%
    #figure(
      image("images/eds-uncoated-loc2.png", width: width),
      caption: [EDS of the uncoated sample (different location).]
    )<fig:eds-uncoated-loc2>
    #figure(
      image("images/eds-coated.png", width: width),
      caption: [EDS of the coated sample. A higher `C` content can be observed.]
    )<fig:eds-coated>
  ]
)
#pagebreak()


#figure(
  image("images/lm-5x-uncoated.png", width: 90%),
  caption: [Micrograph of the uncoated sample at 5x.
    
    _NOTE: The scale bar in this image is incorrect._]
)<fig:lm-5x-uncoated>
#figure(
  image("images/lm-5x-coated.png", width: 95%),
  caption: [Micrograph of the coated sample at 5x.
    
    _NOTE: The scale bar in this image is incorrect._]
)<fig:lm-5x-coated>
#figure(
  image("images/lm-20x-uncoated.png", width: 90%),
  caption: [
    Micrograph of the uncoated sample at 20x.
    
    _NOTE: The scale bar in this image is incorrect._
  ]
)<fig:lm-20x-uncoated>
#figure(
  image("images/lm-50x-uncoated.png", width: 90%),
  caption: [Micrograph of the uncoated sample at 50x.
    
    _NOTE: The scale bar in this image is incorrect._]
)<fig:lm-50x-uncoated>
#figure(
  image("images/lm-50x-coated.png", width: 90%),
  caption: [Micrograph of the coated sample at 50x. The coating obfuscates the microstructure.
    
    _NOTE: The scale bar in this image is incorrect._]
)<fig:lm-50x-coated>
#figure(
  image("images/carbonsteels.png", width: 82%),
  caption: [Microstructure of carbon steels]
) <fig:carbonsteels>