#import "@preview/thmbox:0.2.0": *
#import "@preview/lovelace:0.3.0": *
#import "@preview/physica:0.9.4": *
#import "@preview/unify:0.7.1": num, qty, numrange, qtyrange
#import "@preview/cetz:0.3.2"

#show: thmbox-init()

// Set Page Attributes
#set text(11pt)

#set page(
  paper: "a4",
  columns: 2,
  margin: 1.5cm,
)
#set par(leading: 0.55em, justify: true)
#set text(font: "New Computer Modern")
#show raw: set text(font: "New Computer Modern Mono")
#show heading: set block(above: 1.4em, below: 1em)

#let draw_positive_lens(
  width: 8cm,
  height: 4cm,
  focal: 0.6cm,
  object_x: -0.8cm,
  object_y: 0.5cm,
) = {
  cetz.canvas(
    length: 3cm,
    {
      import cetz.draw: *
      let focal_line_height = 0.1cm

      // Computed Property
      let focal_l_x = -focal
      let focal_r_x = focal

      let ray_via_focal_origin_y = (
        (
          calc.abs(object_x)
            * (
              -object_y / calc.abs(-focal - object_x)
            )
        )
          + object_y
      )

      let image_y = ray_via_focal_origin_y
      let image_x = (
        (calc.abs(image_y) + calc.abs(object_y))
          * (
            calc.abs(focal) / calc.abs(object_y)
          )
      )


      // Axis Line
      set-style(stroke: (thickness: 0.7pt))
      line((-width / 2, 0), (width / 2, 0))

      // Middle Arrow
      set-style(mark: (symbol: "straight"), stroke: (thickness: 0.8pt))
      line((0, -height / 2), (0, height / 2))

      // Images
      set-style(mark: (symbol: none, end: "straight"), stroke: (thickness: 1.5pt))
      line((object_x, 0), (object_x, object_y))
      line((image_x, 0), (image_x, image_y))

      // Focal Points
      set-style(mark: none, stroke: (thickness: 0.7pt))
      line((focal_l_x, -focal_line_height / 2), (focal_l_x, focal_line_height / 2))
      line((focal_r_x, -focal_line_height / 2), (focal_r_x, focal_line_height / 2))

      // Rays
      set-style(mark: none, stroke: (dash: "solid", thickness: 0.2pt))

      // Via Origin
      line((object_x, object_y), (0, 0))
      line((0, 0), (image_x, image_y))

      // Via Parallel
      line((object_x, object_y), (0, object_y))
      line((0, object_y), (image_x, image_y))

      // Via Focal L
      line((object_x, object_y), (0, ray_via_focal_origin_y))
      line((0, ray_via_focal_origin_y), (image_x, ray_via_focal_origin_y))
    },
  )
}



// Title Page
//#place(
//  top + center,
//  scope: "parent",
//  float: true,
//  text()[
//    = Week 4 Notes
//	This week deals with Delauney triangulation.
//  ],
//)
//#pagebreak()



#place(
  top + center,
  scope: "parent",
  float: true,
  text()[
    = Theory of Image Formation in Optical Microscopes
    #v(2em)
  ],
)
#let triang = $upright(T)$

+ Ray optics of the compound microscope
+ The infinity-corrected microscope
  + anatomy of the (infinity-corrected) microscope.
  + Conjugated planes in the microsope.
  + The diffraction in the microscope.
+ Resolution and Numerical Aperture
  + Magnification of the Microscope
  + Diffraction Limit
  + Rayleigh Criteria

== Recap: Lateral Magnificaiton

Consider a model of a positive lens:

#draw_positive_lens(
  width: 8cm,
  height: 3cm,
  focal: 0.6cm,
  object_x: -1.0cm,
  object_y: 0.5cm,
)

#pagebreak()



#place(
  top + center,
  scope: "parent",
  float: true,
  text()[
    = Lab Notes
    #v(2em)
  ],
)

#draw_positive_lens(
  width: 8cm,
  height: 3cm,
  focal: 0.7cm,
  object_x: -1.2cm,
  object_y: 0.5cm,
)
