#import "@preview/theorion:0.3.2": *
#import "@preview/lovelace:0.3.0": *
#import "@preview/physica:0.9.4": *
#import "@preview/unify:0.7.1": num, qty, numrange, qtyrange
#import "@preview/cetz:0.3.1": *
#import "@preview/typsium:0.2.0": ce

#import "@local/rosetypst:0.2.0": *

#show: use-rosetypst


= X-Ray Imaging
== Multiscale Characterization
Diffraction with X-Rays is very good at looking into things like:
- Batteries
- Layered Things
- Polycrystalline Structures
- Grains
- Dislocations in Materials
- Inside of Molecules

For instance, it is possible to image a sample of cast aluminum alloy and deduce where the void defects are.

_This can then be compared to models of stresses and strains!_

#example[
  It's important to be able to characterize the evolution of cracks in wind turbines.

  Using X-Ray tomography, this can be directly examined in 3D.
]



== X-Ray Radiology
The classical thing about radiography is that depth is difficult

#definition[
  The #term[linear attenuation coefficient] is termned as

  $ dv(I, x) = -mu(x) I(x) $

  which solves to:

  $ -ln(I_"det" / I_0) = integral_"path" mu(x) d x $

  #[
    #set align(center)
    #canvas({
      import draw: *

      let pnt_source = (0, 0)
      let pnt_sample = (2.5, 0)
      let pnt_detector = (5, 0)

      circle(pnt_source, radius: (0.25, 0.5), fill: blue.transparentize(50%), stroke: (dash: "dashed"))
      circle(pnt_sample, radius: (0.25, 0.5), fill: none, stroke: gray)
      circle(pnt_detector, radius: (0.25, 0.5), fill: green, stroke: green)

      line(pnt_source, pnt_detector, mark: (end: ">"))


      content(pnt_source, anchor: "north", padding: 0.6, $"Source"$)
      content(pnt_sample, anchor: "north", padding: 0.6, $"Sample"$)
      content(pnt_detector, anchor: "north", padding: 0.6, $"Detector"$)
    })
  ]
]

#definition[
  The #term[attenuation coefficient]

  $ mu prop sum_i (Z_i^4 rho_i) / E^3 $

]



== Radiography Setup
The principle is to sweep, then record angular deviations.

#todo[More detail]



== Algebraic Reconstruction

Consider a 2D slice of a voxel grid:
#[
  #set align(center)
  #canvas(
    length: 0.5cm,
    {
      import draw: *

      draw_xy_axes(x: 11, y: 11)
      grid((0, 0), (10, 10), step: 1)
    },
  )
]

$ mb(M) vb(f) = vb(p) $

...



== Filtered Backprojection
In most commercial instruments, a Fourier Transform-based approach is used.

1. A sample is recorded as $P_theta (t)$.
2. This is "projected" to $vecrow(t, theta)$ chart is recorded.
3. The fourier transform of the $vecrow(t, theta)$ is computed, producing a $vecrow(omega, theta)$ diagram.
4. This is reconstructed back to a $vecrow(u, v)$ fourier space.



== Discrete Tomography
#todo[??]



== Synchrotrons
You build a large circle, and accelerate electrons to near the speed of light with large electromagnets.

They become pulsed, naturally.

When they travel sufficienly fast, the bending of the electrons cause the emission of very powerful, very parallel X-Rays.

=== Brilliance
How many useful X-Rays are there?

$ "brilliance" = "photons" / ("mrad"^2 dot "mm"^2 dot 0.1% dot "sec") $

These days, modern synchrotrons can reach a brilliance of $10^21$.

What can be done with more x-rays?

/ Speed: Hard things can be imaged faster - even to the point of real-time.
/ Materials: Very dense things can be imaged faster.

#example[
  *Speed*: They were able to make a 3D movie of a fly, where it barely manages to flap its wings between frames.

  Aka. they can see inside of the fly, including colors of ex. the muscles, the moving organs, etc. .
]

#example[
  *Resolution*. They can image down to #qty("5", "nm") now!

  _Electrons are still, with their theoretical resolution of #qty("5", "angstrom")._
]

== Phase Contrast Tomography
Consider the incoming wave.
Not only the "shadow" aka. absorption can be used; the phase, too, is available.

As it turns out.

#example[
  Smallest detectable hole at #qty("25", "keV") is:
  / Absorption: #qty("20", "um")
  / Phase: #qty("0.05", "um")
]

== Diffraction Contrast Tomography
Finally, when studying crystals, the diffraction can also be measured to reconstruct the internal structure.
