#import "@preview/theorion:0.3.2": *
#import "@preview/physica:0.9.4": *
#import "@preview/unify:0.7.1": num, qty, numrange, qtyrange
#import "@preview/cetz:0.3.1": *
#import "@preview/typsium:0.2.0": ce
#import "@preview/cetz-plot:0.1.1": plot

#import "@local/rosetypst:0.2.0": *

#show: use-rosetypst

= X-Ray Diffraction Analysis
Once again, #term[Bragg's Law] is the key!

#[
  #set align(center)
  #canvas({
    import draw: *

    let pnt_source = (0, 0)
    let pnt_sample = (2.5, 0)
    let pnt_detector = (5, 0)
    let line_heights = (0, -0.5, -1, -1.5, -2)

    // Draw Reflectors
    for line_height in line_heights {
      line((0, line_height), (6, line_height))
      content((6, line_height), anchor: "west", padding: 0.25, $#(-2*line_height)$)
    }

    // Draw Reflectors
    let transparentization = 0%
    let color = red
    for line_height in line_heights {
      let line_source = 2.5 + line_height
      if line_height == 0 {
        decorations.wave(
          line((0, line_source), (3, line_height), stroke: color.transparentize(transparentization)),
          amplitude: 0.25,
          start: 10%,
          stop: 90%,
          stroke: color,
        )

        line(
          (3, line_height),
          (6, line_source),
          stroke: color.transparentize(transparentization),
          mark: (end: "straight"),
        )
      } else {
        line((0, line_source), (3, line_height), stroke: color.transparentize(transparentization))
        line(
          (3, line_height),
          (6, line_source),
          stroke: color.transparentize(transparentization),
          mark: (end: "straight"),
        )
      }

      transparentization += 20%
    }
  })
]


== Diffractometer Orders
A single-crystal will only show one family of peaks.

#todo[Diagram]

These peaks correspond to hitting one of the crystallographic directions equivalent to parallel planes.

#todo[Use Bragg's law to predict where the peaks "should" occur, based on direct analysis of a crystallographic lattice]

For polycrystals, the peaks will be normally distributed.


== Symmetrical X-Ray Path
Consider the case of diffraction from lattice planes parallel to the surface ($psi = 0$).

#definition(title: "Information Depth of Symmetric X-Ray Paths")[
  #blocklet[
    - $mu$ be the linear absorption coefficient
  ]
  The #term[information depth] $tau$ is the depth from which 63% of the diffracted intensity aka. information comes from:

  $ tau = (sin theta cos psi) / (2mu) = (integral_0^infinity 2e^(-mu x) d x) / (integral_0^infinity e^(-mu x) d x) $

  _Sometimes referred to as #term[penetration depth], or #term[absorption weighted average values]._
]

This measure has a strong dependence on the scattering angle $2theta$, and otherwise has a high penetration depth.


== Asymmetrical X-Ray Path
By using grazing incidence angles, one gets considerably shallower information depths.

#definition(title: "Information Depth of Asymmetric X-Ray Paths")[
  #blocklet[
    - $mu$ be the linear absorption coefficient
  ]
  Then, the #term[information depth] $tau$ is the depth from which 63% of the diffracted intensity aka. information comes from:

  $ tau = 1 / mu (1 / (sin gamma) + 1 / (sin(2theta - gamma))) $
]

In short, the parallel planes are much closer, and the entire thing is much less dependent on the scattering angle $2theta$.



== Exercise: Measuring Tungsten in a Symmetric-Beam Diffractometer
A sample consisting of tungsten is measured in a diffractometer, which is using a symmetrical beam geometry.

The script is setup like this:
```python
import math
import sympy.physics.units as spu
import sympy as sp

diff_angle_deg = sp.Interval(20, 150)
wl_cu = 0.154 * spu.nm
wl_cr = 0.229 * spu.nm
mass_absorp_cu = 171 * spu.cm**2 / spu.g
mass_absorp_cr = 456 * spu.cm**2 / spu.g
density_tungsten = 19.25 * spu.g / spu.cm**3

information_depth = lambda theta, mass_absorp, rho: sp.sin(theta) / (2*mass_absorp * rho)
```



== Applications of XRD for Materials Science
/ Qualitative and Quantitative Phase Analysis: Interpreting $2theta$ and integrated intensity.
/ Line Profile Analysis: The crystallite size and microstrains.
/ Residual Stress Analysis: Lattice strains and macrostresses, interpreting $2theta$ as a function of $psi$ and $phi$.
/ Quantitative Crystallographic Texture: Interpreting integrated intensity as a function of $psi$ and $phi$.



== Interpreting the Diffractogram
Look at the peaks on the diffractogram.
- The width and shape of the peak tells us something about the microstrains and crystallite size.
- The position tells us something about the macrostrain and phase.
- The peak intensity tells us something about the phase and the crystallographic texture.



= Role of Mechanical Stress on Lattice Strains

== Macro- and Microstrains
There are a few different kinds of stressors, described by their order.

/ Macro Stress: $sigma^upright(I)$. Homogeneous over several grains.
  - Characterized by $Delta 2theta$.
/ Micro Stress: $sigma^upright(I I)$. Homogeneous within one grain
  - Characterized by $Delta 2theta$ and $Delta"FWHM"$.
/ Micro Stress: $sigma^upright(I I I)$. Inhomogeneous within one grain
  - Characterized by $Delta"FWHM"$ alone.

== Lattice Strain Analysis
Consider a lattice under compressive strain will behave like
#[
  #set align(center)
  #canvas({
    import draw: *
    draw_xy_axes(x: 5, y: 5)

    arc(
      (3, 0),
      radius: 3,
      start: 0deg,
      delta: 90deg,
      stroke: (paint: black, dash: "dashed"),
    )

    line((0, 0), (60deg, 3), mark: (end: "barbed"))
    content((60deg, 3), anchor: "south-west", padding: 0.5, "compression")

    content((58deg, 2.6), anchor: "east", padding: 0.3, $d_Psi$)

    arc(
      (60deg, 1),
      radius: 1,
      start: 60deg,
      delta: 30deg,
      fill: blue.transparentize(80%),
      mode: "PIE",
    )
    content((73deg, 1), anchor: "south", padding: 0.15, $Psi$)


    let arc_scale = 2.1
    scale(y: arc_scale)
    arc(
      (arc_scale, 0),
      radius: arc_scale,
      start: 0deg,
      delta: 90deg,
      stroke: green,
    )
  })
]

#definition[
  The $sin^2 psi$ method for determining macrostresses uses the #term[biaxial stress-state]:

  $ epsilon^(h k l)_(phi.alt, psi) = 2S_1^(h k l) dot sigma_phi.alt + 1 / 2 S_2^(h k l) dot sigma_phi.alt sin^2 psi $
]

== Oxidation of Bulk Metallic Glass
#todo[Insert info about the research project.]
